@@ -52,7 +52,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
     if len(validated_date_list) == 0:
         print("Cannot find logs file around {}".format(date_in_study))
-        return None
+        return df_logs_combined
 
     for date in validated_date_list:
         date_folder_path = intermediate_participant_path + sep + date
@@ -67,12 +67,15 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
     df_logs_combined = df_logs_combined.dropna(subset=['Local_Time'])
     df_logs_combined.reset_index(inplace=True, drop=True)
-    df_logs_combined["Local_Time"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
-                                         list(df_logs_combined["Local_Time"])]
+    try:
+        df_logs_combined["Local_Time"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
+                                             list(df_logs_combined["Local_Time"])]
 
-    # converter2 = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
-    df_logs_combined['Local_Timestamp'] = pd.Series(map(converter, df_logs_combined["Local_Time"]))
-    df_logs_combined['Date'] = df_logs_combined['Local_Timestamp'].dt.date
+        # converter2 = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+        df_logs_combined['Local_Timestamp'] = pd.Series(map(converter, df_logs_combined["Local_Time"]))
+        df_logs_combined['Date'] = df_logs_combined['Local_Timestamp'].dt.date
+    except IndexError:
+        raise Exception("IndexError: list index out of range : " + intermediate_participant_path + sep + date_in_study + str(list(df_logs_combined["Local_Time"])))
 
     return df_logs_combined
 
@@ -123,8 +126,12 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
     # Read, parse and combine related intermediate file
     df_logs_combined = combine_intermediate_file(intermediate_participant_path, date_in_study)
 
-    # Match the combined parsed intermediate file with prompt feature data frame
-    battery_level_column, charging_status_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+    if df_logs_combined.shape[0] > 0:
+        # Match the combined parsed intermediate file with prompt feature data frame
+        battery_level_column, charging_status_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+    else:
+        battery_level_column = ["NF"] * len(prompt_local_datetime_series)
+        charging_status_column = ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     battery_level_column_transformed = transform(battery_level_column)
